@@ -7,6 +7,7 @@ __all__ = [
 ]
 
 from typing import List, Callable
+
 import urwid
 
 
@@ -26,7 +27,7 @@ class ConsolesColumns(urwid.Columns):
 
 	# self.keypress(1,1)
 
-	def CreateNewTitleName(self, title_names: List[str]):
+	def UpdateTitle(self, title_names: List[str]):
 		"""
 		Создать новые консоли
 		"""
@@ -42,6 +43,9 @@ class ConsolesColumns(urwid.Columns):
 		self.__index_column[0] = 0
 		self.__index_column[1] = len(title_names) - 1
 
+	def update_widget(self):
+		self.get_focus()
+
 	def SendTextInIndex(self, index_: int, text_: str):
 		"""
 		Вставить текст в текстовое поле по его индексу:
@@ -50,7 +54,7 @@ class ConsolesColumns(urwid.Columns):
 		self.contents[index_][0].body_txt.txt.insert_text(text_)
 		self.contents[index_][0].body_txt.txt.set_edit_pos(0)
 
-	def SendSelfInfo(self, text: str):
+	def PrintInfo(self, text: str):
 		self.SendTextInIndex(0, text)
 
 	def keypress(self, size, key):
